@@ -1,15 +1,18 @@
 from . import _version
 from .odata_nodes import ODataProductNode, ODataAttributeNode
 from .odata_services_nodes import ODataServiceNodeCSC, \
+    ODataServiceNodeList, \
     ODataServiceNodeDias, ODataServiceNodeDhus
-from .odata_utils import ODataQueryPredicate
+from .odata_utils import ODataQueryPredicate, OdataServiceType
 
 __version__ = _version.get_versions()['version']
 __all__ = [
+    'ODataServiceNodeList',
     'ODataServiceNodeCSC',
     'ODataServiceNodeDias',
     'ODataServiceNodeDhus',
     'ODataProductNode',
     'ODataAttributeNode',
-    'ODataQueryPredicate'
+    'ODataQueryPredicate',
+    'OdataServiceType'
 ]
