@@ -112,6 +112,8 @@ class ODataProductNode(OdataNode):
         pass
 
     def has_impl(self, impl: type) -> bool:
+        if impl == ODataProductNode:
+            return True
         if self.type_service == OdataServiceType.ONDA_DIAS:
             online = not self.get_attribute('offline')
         else:
@@ -120,6 +122,8 @@ class ODataProductNode(OdataNode):
 
     def get_impl(self, impl: type, **kwargs) -> Any:
         if self.has_impl(impl):
+            if impl == ODataProductNode:
+                return self
             return ODataUtils.req_product_download(self, self.__uuid,
                                                    kwargs.get('start', None),
                                                    kwargs.get('end', None))
