@@ -7,7 +7,8 @@ from abc import ABC, abstractmethod
 from drb import DrbNode
 from drb.path import ParsedPath
 from drb.predicat import Predicate
-from drb.exceptions import DrbException
+from drb.exceptions import DrbException, DrbFactoryException
+from drb.factory import DrbFactoryResolver
 
 from typing import Any, Dict, Iterable, List, Optional, Tuple, Union
 
@@ -53,7 +54,9 @@ class ODataServiceNode(OdataNode, ABC):
 
     @property
     def children(self) -> List[DrbNode]:
-        return ODataFilteredList(self)
+        filtered_list = ODataFilteredList(self)
+        children_list = ODataServiceNodeList(filtered_list)
+        return children_list
 
     def get_attribute(self, name: str, namespace_uri: str = None) -> Any:
         raise DrbException('ODataNode has no attribute')
@@ -79,7 +82,7 @@ class ODataServiceNode(OdataNode, ABC):
         raise DrbException(f"ODataNot doesn't support {impl} implementation")
 
     @abstractmethod
-    def prepare_filter(self, user_filter: str, default: str) -> str:
+    def prepare_filter(self, user_filter: str) -> str:
         raise NotImplementedError
 
     @abstractmethod
@@ -134,8 +137,46 @@ class ODataServiceNode(OdataNode, ABC):
 
     def __getitem__(self, item):
         if isinstance(item, int):
-            return self.children[item]
-        return self.__retrieve_child(item)
+            children_list = self.children
+            resolved_node = children_list[item]
+            return resolved_node
+
+        elif isinstance(item, uuid.UUID):
+            node = self.__retrieve_child(item)
+            try:
+                _, resolved_node = DrbFactoryResolver().resolve(node)
+                return resolved_node
+            except DrbFactoryException:
+                return node
+
+        elif isinstance(item, ODataQueryPredicate):
+            filtered_list = self.__retrieve_child(item)
+            children_list = ODataServiceNodeList(filtered_list)
+            return children_list
+
+        elif isinstance(item, str):
+            node = self.__retrieve_child(item)
+            try:
+                _, resolved_node = DrbFactoryResolver().resolve(node)
+                return resolved_node
+            except DrbFactoryException:
+                return node
+
+        elif isinstance(item, tuple):
+            node = self.__retrieve_child(item)
+            try:
+                _, resolved_node = DrbFactoryResolver().resolve(node)
+                return resolved_node
+            except DrbFactoryException:
+                return node
+
+        elif isinstance(item, slice):
+            children_list = self.children
+            sliced_list = children_list[item]
+            return sliced_list
+
+        else:
+            raise TypeError
 
 
 class ODataServiceNodeCSC(ODataServiceNode):
@@ -145,17 +186,18 @@ class ODataServiceNodeCSC(ODataServiceNode):
         self._type = OdataServiceType.CSC
         return self._type
 
-    def prepare_filter(self, user_filter: str, default: str) -> str:
-        date = datetime.datetime.utcnow().strftime('%Y-%m-%dT%H:%M:%SZ')
-        if user_filter is None:
-            return f'{default} lt {date}'
-        if default in user_filter:
-            return user_filter
-        return f"({user_filter}) and {default} lt {date}"
-
     def retrieve_default_criteria(self) -> str:
         return 'PublicationDate'
 
+    def prepare_filter(self, user_filter: str) -> str:
+        date = datetime.datetime.utcnow().strftime('%Y-%m-%dT%H:%M:%SZ')
+        if user_filter is None:
+            return f'{self.retrieve_default_criteria()} lt {date}'
+        if self.retrieve_default_criteria() in user_filter:
+            return user_filter
+        return f"{user_filter} and" \
+               f" {self.retrieve_default_criteria()} lt {date}"
+
     @property
     def namespace_uri(self) -> Optional[str]:
         return 'OData.CSC'
@@ -189,21 +231,22 @@ class ODataServiceNodeDhus(ODataServiceNode):
         self._type = OdataServiceType.DHUS
         return self._type
 
-    def prepare_filter(self, user_filter: str, default: str) -> str:
+    def retrieve_default_criteria(self) -> str:
+        return 'CreationDate'
+
+    def prepare_filter(self, user_filter: str) -> str:
         date = datetime.datetime.utcnow().strftime('%Y-%m-%dT%H:%M:%S.0Z')
         if user_filter is None:
-            return f'{default} lt {date}'
-        if default in user_filter:
+            return f'{self.retrieve_default_criteria()} lt {date}'
+        if self.retrieve_default_criteria() in user_filter:
             return user_filter
-        return f"({user_filter}) and {default} lt {date}"
+        return f"{user_filter} and " \
+               f"{self.retrieve_default_criteria()} lt {date}"
 
     @property
     def children(self) -> List[DrbNode]:
         return ODataFilteredList(self, page_size=10)
 
-    def retrieve_default_criteria(self) -> str:
-        return 'CreationDate'
-
     @property
     def namespace_uri(self) -> Optional[str]:
         return 'OData.DHuS'
@@ -237,17 +280,17 @@ class ODataServiceNodeDias(ODataServiceNode):
         self._type = OdataServiceType.ONDA_DIAS
         return self._type
 
-    def prepare_filter(self, user_filter: str, default: str) -> str:
-        if user_filter is None:
-            return f"%22creationDate:[1900-05-10T00:00:00.000Z TO NOW]%22"
-        if default in user_filter:
-            return user_filter
-        return f"%22({user_filter}) and creationDate:" \
-               f"[1900-05-10T00:00:00.000Z TO NOW]%22"
-
     def retrieve_default_criteria(self) -> str:
         return 'creationDate'
 
+    def prepare_filter(self, user_filter: str) -> str:
+        if user_filter is None:
+            return f"%22creationDate:[1900-05-10T00:00:00.000Z TO NOW]%22"
+        if self.retrieve_default_criteria() in user_filter:
+            return user_filter
+        return f"%22{user_filter} and creationDate:" \
+               f"[1900-05-10T00:00:00.000Z TO NOW]%22"
+
     @property
     def namespace_uri(self) -> Optional[str]:
         return 'Ens'
@@ -284,7 +327,7 @@ class ODataFilteredList(list):
         self._page_size = page_size
         self._odata = odata
         default = odata.retrieve_default_criteria()
-        self._filter = odata.prepare_filter(qfilter, default)
+        self._filter = odata.prepare_filter(qfilter)
         self._order = self.__prepare_order(qorder, default)
 
     @classmethod
@@ -294,10 +337,8 @@ class ODataFilteredList(list):
         return user_order
 
     def __perform_query(self):
-        count = False
-
         buffer, self._count = ODataUtils.req_svc_products(
-            self._odata, count=self._count == -1, filter=self._filter,
+            self._odata, count=self._count, filter=self._filter,
             order=self._order, skip=self._skip, top=self._page_size)
 
         if self._count == -1 and not ODataUtils.is_count_accepted_in_request(
@@ -409,6 +450,83 @@ class ODataFilteredList(list):
         raise NotImplementedError
 
 
+class ODataServiceNodeList(list):
+
+    def __init__(self, odata: Union[List[DrbNode], ODataFilteredList]):
+        super().__init__()
+        self._odata = odata
+
+    def __getitem__(self, item):
+
+        if isinstance(item, slice):
+            sliced_list = self._odata[item]
+            result = ODataServiceNodeList(sliced_list)
+            return result
+
+        elif isinstance(item, int):
+            if item <= len(self._odata):
+                node = self._odata[item]
+                try:
+                    _, resolved_node = DrbFactoryResolver().resolve(node)
+                    return resolved_node
+                except DrbFactoryException:
+                    return node
+            else:
+                raise IndexError
+        else:
+            raise KeyError(f'Invalid key: {type(item)}')
+
+    def __iter__(self):
+        def gen():
+            i = 0
+            while i < len(self._odata):
+                node = self._odata[i]
+                try:
+                    _, resolved_node = DrbFactoryResolver().resolve(node)
+                except DrbFactoryException:
+                    return node
+                yield resolved_node
+                i += 1
+        return gen()
+
+    def __len__(self):
+        count = len(self._odata)
+        return count
+
+    def append(self, obj: Any) -> None:
+        raise NotImplementedError
+
+    def clear(self) -> None:
+        raise NotImplementedError
+
+    def copy(self) -> List[ODataProductNode]:
+        raise NotImplementedError
+
+    def count(self, value: Any) -> int:
+        raise NotImplementedError
+
+    def extend(self, iterable: Iterable[ODataProductNode]) -> None:
+        raise NotImplementedError
+
+    def index(self, value: Any, start: int = ..., stop: int = ...) -> int:
+        raise NotImplementedError
+
+    def insert(self, index: int, obj: ODataProductNode) -> None:
+        raise NotImplementedError
+
+    def pop(self, index: int = ...) -> ODataProductNode:
+        raise NotImplementedError
+
+    def remove(self, value: Any) -> None:
+        raise NotImplementedError
+
+    def reverse(self) -> None:
+        raise NotImplementedError
+
+    def sort(self: List, *, key: None = ..., reverse: bool = ...) -> None:
+        raise NotImplementedError
+
+
 class ProductList(list):
     """
     Specific read only list to access to OData CSC Product entities:
