@@ -122,9 +122,10 @@ class ODataUtils:
         if 'top' in kwargs.keys() and kwargs['top'] is not None:
             params['$top'] = kwargs['top']
 
-        if 'count' in kwargs.keys() and kwargs['count']:
+        if 'count' in kwargs.keys():
             ret_count = True
-            if ODataUtils.is_count_accepted_in_request(odata):
+            count = kwargs['count']
+            if count == -1 and ODataUtils.is_count_accepted_in_request(odata):
                 params['$count'] = 'true'
 
         query = '&'.join(map(lambda k: f'{k[0]}={k[1]}', params.items()))
@@ -135,7 +136,7 @@ class ODataUtils:
             if '@odata.count' in data.keys():
                 return data['value'], data['@odata.count']
             else:
-                return data['value'], -1
+                return data['value'], count
         return data['value']
 
     @staticmethod
